opml2json is a simple python module that convert opml to json 

### setup
    * git clone https://github.com/vishnu012/opml2json && cd opml2json

    * python3 setup.py install

### usage
    python3 -m opml2json -f filename.opml
